@@ -33,7 +33,8 @@ const Gio = imports.gi.Gio;
 
 const PRESETS_PATH = 'data/presets/presets';
 const LOCALES_PATH = 'dist/locales';
-const PRESET_TYPES = [ 'amenity',
+const PRESET_TYPES = [ 'aeroway',
+                       'amenity',
                        'leisure',
                        'office',
                        'place',
@@ -116,7 +117,7 @@ function processLocales(basePath) {
 }
 
 function outputJson() {
-    print(JSON.stringify(OUTPUT));
+    print(JSON.stringify(OUTPUT, null, 2));
 }
 
 function main(args) {
