@@ -35,6 +35,7 @@ const FavoritesPopover = imports.favoritesPopover;
 const Geoclue = imports.geoclue;
 const LayersPopover = imports.layersPopover;
 const LocationServiceNotification = imports.locationServiceNotification;
+const MapSource = imports.mapSource;
 const MapView = imports.mapView;
 const PlaceEntry = imports.placeEntry;
 const PlaceStore = imports.placeStore;
@@ -79,6 +80,10 @@ const MainWindow = new Lang.Class({
 
         this._overlay.add(this._mapView);
 
+        if (!this.application.local_tile_path) {
+            this._overlay.add_overlay(new MapSource.AttributionLogo());
+        }
+
         this._mapView.gotoUserLocation(false);
 
         this._sidebar = this._createSidebar();
@@ -136,9 +141,10 @@ const MainWindow = new Lang.Class({
         let sidebar = new Sidebar.Sidebar(this._mapView);
         Application.routeService.query.connect('notify',
                                                this._setRevealSidebar.bind(this, true));
-        sidebar.bind_property('reveal-child',
-                              this._mapView, 'routeVisible',
-                              GObject.BindingFlags.BIDIRECTIONAL);
+
+        this._toggleSidebarButton.bind_property('active',
+                                                this._mapView, 'routeVisible',
+                                                GObject.BindingFlags.BIDIRECTIONAL);
         this.application.bind_property('connected',
                                        sidebar, 'visible',
                                        GObject.BindingFlags.DEFAULT);
@@ -353,26 +359,29 @@ const MainWindow = new Lang.Class({
 
     _onGotoUserLocationActivate: function() {
         let message;
-        switch(Application.geoclue.state) {
-        case Geoclue.State.FAILED:
-            message = _("Failed to connect to location service");
-            Application.notificationManager.showMessage(message);
-            break;
 
-        case Geoclue.State.TIMEOUT:
-            message = _("Position not found");
-            Application.notificationManager.showMessage(message);
-            break;
-
-        case Geoclue.State.OFF:
-            let notification = this._getLocationServiceNotification();
-            Application.notificationManager.showNotification(notification);
-            break;
-
-        default:
+        if (Application.geoclue.state === Geoclue.State.ON) {
             this._mapView.gotoUserLocation(true);
-            break;
+            return;
         }
+
+        Application.geoclue.start((function() {
+            switch(Application.geoclue.state) {
+            case Geoclue.State.FAILED:
+                message = _("Failed to connect to location service");
+                Application.notificationManager.showMessage(message);
+                break;
+
+            case Geoclue.State.DENIED:
+                let notification = this._getLocationServiceNotification();
+                Application.notificationManager.showNotification(notification);
+                break;
+
+            default:
+                this._mapView.gotoUserLocation(true);
+                break;
+            }
+        }).bind(this));
     },
 
     _printRouteActivate: function() {
